@@ -19,6 +19,9 @@ from rrshare.rqUtil import (rq_util_date_today,
                             rq_util_if_trade, 
                             rq_util_datetime_to_strdate)
 
+from rrshare.rqSU import save_swl1_realtime
+
+from rrshare.rqFactor import swl1_index_realtime_prs
 
 today_ = rq_util_datetime_to_strdate(datetime.date.today())
 
@@ -64,9 +67,13 @@ def job_update_stock_PRS_pre():
 def job_update_stock_PRS_new():
     update_stock_PRS_new()
 
+def job_update_swl1_realtime_prs():
+    save_swl1_realtime()
+    swl1_index_realtime_prs()
 
 def job_update_ROE_CF_SR_INC():
-    update_roe_cf_sr_inc()
+    #update_roe_cf_sr_inc()
+    pass
 
 
 def dojob():
@@ -84,16 +91,25 @@ def dojob():
     # realtime PRS_new # run now() first
     scheduler.add_job(job_update_stock_PRS_new, 'interval', minutes=1, next_run_time=datetime.datetime.now(),
                       start_date='2021-04-05 9:28:00', end_date='2021-12-31 23:01:00', id='job_stock_PRS_new')
+
+    # realtime swl1_prs
+    scheduler.add_job(job_update_swl1_realtime_prs, 'interval', minutes=1, next_run_time=datetime.datetime.now(),
+                      start_date='2021-05-05 9:26:00', end_date='2021-12-31 23:01:00', id='job_swl1_prs_realtime')
+
+
     # update_ROE_CF_SR_INC
-   # scheduler.add_job(job_update_ROE_CF_SR_INC, 'cron', day_of_week='mon-sun',next_run_time=datetime.datetime.now(),
+    # scheduler.add_job(job_update_ROE_CF_SR_INC, 'cron', day_of_week='mon-sun',next_run_time=datetime.datetime.now(),
     #                  hour=8, minute=10, id='job_update_ROE_CF_SR_INC')
 
     scheduler.start()
     pass
 
 #job_start_first_all()
+
+
 def main_timer():
     scheduler.add_job(job_update_stock_PRS_new, 'interval', minutes=1, next_run_time=datetime.datetime.now(), id='job_stock_PRS_new')
+    scheduler.add_job(job_update_swl1_realtime_prs,'interval', minutes=1, next_run_time=datetime.datetime.now(), id='job_swl1_prs_realtime')
 
     while  rq_util_if_trade(today_) and rq_util_if_tradetime():
         scheduler.start()
