@@ -1,9 +1,9 @@
-from rrshare.rqFactor import update_swl_rs_valuation
+from rrshare.rqFactor import update_swl_all_main
 
 
 def record_swl_rs_valuation():
-    update_swl_rs_valuation()
+    update_swl_all_main()
 
 
 if __name__ == '__main__':
-    record_swl_rs_valuation()
\ No newline at end of file
+    record_swl_rs_valuation()
