@@ -54,6 +54,7 @@ end = datetime.datetime(year, month, day, 15, 2, 5)
 
 st.write('last reload',current, 'last tradedate:',lastTD)
 
+L = ['L1','L2','L3']
 
 def out_df_items(df):
     df = df.round(2)
@@ -63,16 +64,30 @@ def out_df_items(df):
     return df, date, time
 
 
+def swl_rs_valuation_all(level):
+    table_name = f'swl_rs_valuation_{level}'
+    print(table_name)
+    data = pd.read_sql_table(table_name, conn)
+    st.text(f'申万行业相对强度和估值_{level}')
+    st.dataframe(data,width=1400, height=900)
+    pass
+
+
 def swl_rs_valuation():
-    data = pd.read_sql_table('swl1_rs_L1',conn)
+    data = pd.read_sql_table('swl1_rs_L1',conn) # swl1_rs_reaktime_L1
     df = data.copy()
     df.rename(columns={'pct_change':'pct_chg'}, inplace=True)
     df = df.round(2)
     #swl
-    st.text(f'申万行业相对强度和估值')#: {df.trade_date.unique()}')
+    st.text(f'申万行业相对强度和估值-L1实时')#: {df.trade_date.unique()}')
     #df.drop(columns=['trade_date'], inplace=True)
     st.dataframe(df, width=1400, height=900)
 
+    for level in L:
+        swl_rs_valuation_all(level)
+
+    pass
+
 
 def write_stock_RS_OH_MA():
     st.text('相对强度 ')
@@ -126,7 +141,7 @@ def stock_select_PRS(table_name='stock_select_PRS'):
         df.rename(columns={'name':'display_name'},inplace=True)
         #print(df)
         data = out_df_items(df)
-        st.text('相对强度 top')
+        st.write('相对强度 top', str(len(df)), '只')
         st.write(data[1], data[2])
         st.dataframe(data[0], width=1200, height=600)
     except Exception as e:
@@ -142,12 +157,11 @@ def stock_fundmentals(): #TODO
     #st.write(df[df.code  == code].T)
     #st.dataframe(df.T, width=1400, height=500)
     st.write("wencai","http://www.iwencai.com/unifiedwap/home/index?qs=pc_~soniu~info~all~homepage~enter")
-
-
     pass
 
 
 def stock_infomation():
+    st.write("wencai","http://www.iwencai.com/unifiedwap/home/index?qs=pc_~soniu~info~all~homepage~enter")
     st.write('concept','http://q.10jqka.com.cn/gn/')
     #x = st.slider('x')
     st.text('业绩预告')
